@@ -7,7 +7,7 @@ _logger = logging.getLogger(__name__)
 
 from pydantic import BaseModel
 
-from .console import set_dir
+from .console import set_dir, console
 
 class Config(BaseModel):
     data_dir    : Path
@@ -24,6 +24,7 @@ class Config(BaseModel):
         working_dir.mkdir(parents=True, exist_ok=True)
         _logger.info("Set up working directories for %s", working_dir)
 
+        console.print(f"Changing to {working_dir}")
         with set_dir(working_dir):
             yield
         _logger.info("Leaving working directory %s", working_dir)
